---
name: Bug report
about: Create a report to help us improve

---

Describe your issue here.

## Your environment

* version of LIVVkit
* Did you install LIVVkit via pypi, conda, or was it provided to you? 
* What type of machine are you working on?

## Steps to reproduce

* How can we reproduce this issue?  
* Do we need any external data to reproduce this issue? 
* If so, where can we find it?

## LIVVkit output

```
Please copy and past the command you used and **all** following output here

```
